Oaskit.Spec.Parameter (oaskit v0.12.0)

Copy Markdown View Source

Representation of the Parameter Object in OpenAPI Specification.

Summary

Functions

Returns the given parameter with the expected default values for style and explode.

Functions

from_controller!(name, ref)

json_schema()

with_defaults(parameter)

Returns the given parameter with the expected default values for style and explode.

Default style are:

  • :form for query and cookie parameters
  • :simple for header and path parameters

Default explode is true when the style is :form, false otherwise.

See the specifications for more information.